# -*- coding: utf-8 -*-
"""
Calculate gunning fog readability score
"""
__title__ = 'py-readabilitiy-metrics'
__version__ = '0.21.1'
__author__ = 'Carmine DiMascio'
__license__ = 'MIT'
__copyright__ = 'Copyright 2018 Carmine DiMascio'

from .readability import Readability



from readability.exceptions import ReadabilityException


class Result:
    def __init__(self, score, grade_level):
        self.score = score
        self.grade_level = grade_level

    def __str__(self):
        return "score: {}, grade_level: '{}'". \
            format(self.score, self.grade_level)


class GunningFog:
    def __init__(self, stats):
        self._stats = stats
        if stats.num_words < 100:
            raise ReadabilityException('100 words required.')

    def score(self):
        score = self._score()
        return Result(
            score=score,
            grade_level=self._grade_level(score)
        )

    def _score(self):
        s = self._stats
        print(s)
        word_per_sent = s.num_words / s.num_sentences
        poly_syllables_per_word = s.num_gunning_complex / s.num_words
        return 0.4 * (word_per_sent + 100 * poly_syllables_per_word)

    def _grade_level(self, score):
        rounded = round(score)
        if rounded < 6:
            return 'na'
        elif rounded >= 6 and rounded <= 12:
            return str(rounded)
        elif rounded >= 13 and rounded <= 16:
            return 'college'
        else:
            return 'college_graduate'



#!/user/bin/env python

from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='py-readability-metrics',
    version='0.21.1',
    author='Carmine DiMAscio',
    author_email='cdimascio@gmail.com',
    description='Calculate readability scores. e.g. Flesch, Flesch-Kincaid, and more',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/cdimascio/py-readability-metrics',
    keywords="readability metrics text difficulty grade level",
    packages=find_packages(exclude=['tests']),
    package_data={'readability': ['data', 'data/dale_chall_porterstem.txt']},
    include_package_data=True,
    license='MIT',
    install_requires=[
         'nltk'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)



from .text import Analyzer
from .scorers import ARI, ColemanLiau, DaleChall, Flesch, FleschKincaid, GunningFog


class Readability:
    def __init__(self, text):
        self.analyzer = Analyzer(text)

    def ari(self):
        """Calculate Automated Readability Index (ARI)."""
        return ARI(self.analyzer.statistics).score()

    def coleman_liau(self):
        """Calculate Coleman Liau Index."""
        return ColemanLiau(self.analyzer.statistics).score()

    def dale_chall(self):
        """Calculate Dale Chall."""
        return DaleChall(self.analyzer.statistics).score()

    def flesch(self):
        """Calculate Flesch Reading Ease score."""
        return Flesch(self.analyzer.statistics).score()

    def flesch_kincaid(self):
        """Calculate Flesch Kincaid Grade Level."""
        return FleschKincaid(self.analyzer.statistics).score()

    def gunning_fog(self):  # , abbr=None, hyphen=None, vars={}):
        """Calculate Gunning Fog score."""
        return GunningFog(self.analyzer.statistics).score()
